@@ -50,6 +50,7 @@ Returns a list of services currently registered with the service manager.
 
 sub active_services { @{$_[0]->_active_services} }
 sub services { grep !$_->abstract, $_[0]->_services }
+sub add_service { push @{$_[0]->_active_services}, $_[1] }
 
 sub new {
     my( $class ) = @_;
@@ -71,34 +72,50 @@ C<initialized> property to true.
 =cut
 
 sub initialize {
-    my( $self, $wxebug ) = @_;
+    my( $self ) = @_;
 
     foreach my $service ( $self->active_services ) {
         next if $service->initialized;
-        $service->initialize( $wxebug );
+        $service->service_manager( $self )
+          if $service->can( 'service_manager' );
+        $service->initialize( $self );
         $service->initialized( 1 );
     }
 }
 
-=head2 load_state
+=head2 load_configuration
 
-  $sm->load_state;
+  $sm->load_configuration;
 
-Calls C<load_state> on all service instances.
+Calls C<load_configuration> on all service instances.
+
+=head2 maybe_call_method
+
+  $sm->maybe_call_method( $method, @args );
+
+Calls method C<$method> on all active services that provide it, passing
+C<@args> as arguments.
 
 =cut
 
-sub load_state {
+sub load_configuration {
     my( $self ) = @_;
 
-    $_->load_state foreach $self->active_services;
+    $_->load_configuration foreach $self->active_services;
+}
+
+sub maybe_call_method {
+    my( $self, $method, @args ) = @_;
+
+    $_->$method( @args ) foreach grep $_->can( $method ),
+                                      $self->active_services;
 }
 
 =head2 finalize
 
   $sm->finalize( $wxebug );
 
-Calls C<save_state> on all service instances, then calls C<finalize>
+Calls C<save_configuration> on all service instances, then calls C<finalize>
 on them and sets their C<finalized> property to true.
 
 Important: the C<initialized> property is still true even after
@@ -110,7 +127,7 @@ sub finalize {
     my( $self, $wxebug ) = @_;
 
     # distinguish between explicit and implicit state saving?
-    $_->save_state foreach $self->active_services;
+    $_->save_configuration foreach $self->active_services;
     foreach my $service ( $self->active_services ) {
         next if $service->finalized;
         $service->finalize;
@@ -124,18 +141,20 @@ sub finalize {
 
 Returns an active service with the given name, or C<undef> if none is
 found.  If the service has not been initialized, calls C<inititialize>
-as well, but not C<load_state>.
+as well, but not C<load_configuration>.
 
 =cut
 
 sub get_service {
-    my( $self, $wxebug, $name ) = @_;
+    my( $self, $name ) = @_;
     my( $service, @rest ) = grep $_->service_name eq $name,
                                  $self->active_services;
 
     # @rest can be nonempty only if two clashing services exist
     unless( $service->initialized ) {
-        $service->initialize( $wxebug );
+        $service->service_manager( $self )
+          if $service->can( 'service_manager' );
+        $service->initialize( $self );
         $service->initialized( 1 );
     }
     return $service;
@@ -147,4 +166,30 @@ L<Devel::ebug::Wx::Service::Base>
 
 =cut
 
+# FIXME document
+package Devel::ebug::Wx::ServiceManager::Holder;
+
+use strict;
+use base qw(Exporter);
+
+$INC{'Devel/ebug/Wx/ServiceManager/Holder.pm'} = __FILE__;
+our @EXPORT = qw(AUTOLOAD service_manager get_service);
+our %EXPORT_TAGS = ( 'noautoload' => [ qw(service_manager get_service) ] );
+
+sub service_manager { # the usual getter/setter
+    return $_[0]->{service_manager} = $_[1] if @_ > 1;
+    return $_[0]->{service_manager};
+}
+
+# remap ->xxx_yy_service to ->get_service( 'xxx_yy' )
+our $AUTOLOAD;
+sub AUTOLOAD {
+    my $self = shift;
+    return if $AUTOLOAD =~ /::DESTROY$/;
+    ( my $sub = $AUTOLOAD ) =~ s/.*::(\w+)_service$/$1/;
+    return $self->get_service( $1 );
+}
+
+sub get_service { $_[0]->service_manager->get_service( $_[1] ) }
+
 1;
